@@ -20,7 +20,7 @@
 #include <ucommon/ucommon.h>
 #endif
 
-NAMESPACE_UCOMMON
+namespace ucommon {
 
 /**
  * Compiled script container.  This class holds the image of a
@@ -62,7 +62,7 @@ public:
      */
     typedef const char *(*check_t)(Script *img, Script::header *scr, Script::line_t *line);
 
-    /**
+    /**NAMESPACE_UCOMMON
      * A structure to introduce new core commands to the runtime engine.
      * This is typically passed to assign as an array.  Entries with no
      * runtime method (method = NULL) are only processed at compile-time.
@@ -155,7 +155,7 @@ public:
          * @param scr header to link with.
          */
         inline void link(header *scr)
-            {Next = scr;};
+            {Next = scr;}
     };
 
     /**
@@ -481,19 +481,19 @@ public:
     method_t looping(void);
 
     inline unsigned getErrors(void)
-        {return errors;};
+        {return errors;}
 
     inline LinkedObject *getListing(void)
-        {return errlist.begin();};
+        {return errlist.begin();}
 
     inline const char *getFilename(void)
-        {return filename;};
+        {return filename;}
 
     inline bool isStrict(void)
-        {return global != NULL;};
+        {return global != NULL;}
 
     inline unsigned getLines(void)
-        {return lines;};
+        {return lines;}
 
 private:
     friend class strict;
@@ -520,7 +520,7 @@ private:
     LinkedObject *headers;
 };
 
-END_NAMESPACE
+} // namespace ucommon
 
 #endif
 
