@@ -23,7 +23,7 @@
 #include <ccscript.h>
 #include <ctype.h>
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 static const char *getArgument(Script::line_t *line, unsigned *index)
 {
@@ -1087,3 +1087,5 @@ const char *Script::checks::chkIgnore(Script *img, Script::header *scr, Script::
 {
     return NULL;
 }
+
+} // namespace ucommon
