@@ -22,7 +22,7 @@
 #include <ucommon/export.h>
 #include <ccscript.h>
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 bool Script::methods::scrDo(void)
 {
@@ -821,3 +821,4 @@ bool Script::methods::scrSet(void)
     return true;
 }
 
+} // namespace ucommon
