@@ -23,7 +23,7 @@
 #include <ccscript.h>
 #include <ctype.h>
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 static Script::keyword_t *keywords = NULL;
 static unsigned long icounter = 0;
@@ -1324,3 +1324,4 @@ char *Script::get(char *list, unsigned index)
     return NULL;
 }
 
+} // namespace ucommon
